@@ -17,13 +17,13 @@
 #include "pkg.h"
 #include "bsdstubs.h"
 
-#define PKG_CFLAGS			(1<<1)
 #define PKG_CFLAGS_ONLY_I		(1<<2)
 #define PKG_CFLAGS_ONLY_OTHER		(1<<3)
-#define PKG_LIBS			(1<<4)
+#define PKG_CFLAGS			(PKG_CFLAGS_ONLY_I|PKG_CFLAGS_ONLY_OTHER)
 #define PKG_LIBS_ONLY_LDPATH		(1<<5)
 #define PKG_LIBS_ONLY_LIBNAME		(1<<6)
 #define PKG_LIBS_ONLY_OTHER		(1<<7)
+#define PKG_LIBS			(PKG_LIBS_ONLY_LDPATH|PKG_LIBS_ONLY_LIBNAME|PKG_LIBS_ONLY_OTHER)
 #define PKG_MODVERSION			(1<<8)
 #define PKG_REQUIRES			(1<<9)
 #define PKG_REQUIRES_PRIVATE		(1<<10)
@@ -59,19 +59,37 @@ FILE *error_msgout = NULL;
 static bool
 fragment_has_system_dir(pkg_fragment_t *frag)
 {
+	int check_flags = 0;
+	char *check_paths = NULL;
+	char *save, *chunk;
+	bool ret = false;
+
 	switch (frag->type)
 	{
 	case 'L':
-		if ((want_flags & PKG_KEEP_SYSTEM_LIBS) == 0 && !strcasecmp(SYSTEM_LIBDIR, frag->data))
-			return true;
-	case 'I':
-		if ((want_flags & PKG_KEEP_SYSTEM_CFLAGS) == 0 && !strcasecmp(SYSTEM_INCLUDEDIR, frag->data))
-			return true;
-	default:
+		check_flags = PKG_KEEP_SYSTEM_LIBS;
+		check_paths = strdup(SYSTEM_LIBDIR);
 		break;
+	case 'I':
+		check_flags = PKG_KEEP_SYSTEM_CFLAGS;
+		check_paths = strdup(SYSTEM_INCLUDEDIR);
+		break;
+	default:
+		return false;
 	}
 
-	return false;
+	for (chunk = strtok_r(check_paths, ":", &save); chunk != NULL; chunk = strtok_r(NULL, ":", &save))
+	{
+		if ((want_flags & check_flags) == 0 && !strcmp(chunk, frag->data))
+		{
+			ret = true;
+			break;
+		}
+	}
+
+	free(check_paths);
+
+	return ret;
 }
 
 static void
@@ -103,10 +121,14 @@ print_cflags(pkg_list_t *list)
 	PKG_FOREACH_LIST_ENTRY(list->head, node)
 	{
 		pkg_fragment_t *frag = node->data;
+		int got_flags = 0;
 
-		if ((want_flags & PKG_CFLAGS_ONLY_I) == PKG_CFLAGS_ONLY_I && frag->type != 'I')
-			continue;
-		else if ((want_flags & PKG_CFLAGS_ONLY_OTHER) == PKG_CFLAGS_ONLY_OTHER && frag->type == 'I')
+		if (frag->type == 'I')
+			got_flags = PKG_CFLAGS_ONLY_I;
+		else
+			got_flags = PKG_CFLAGS_ONLY_OTHER;
+
+		if ((want_flags & got_flags) == 0)
 			continue;
 
 		print_fragment(frag);
@@ -121,12 +143,16 @@ print_libs(pkg_list_t *list)
 	PKG_FOREACH_LIST_ENTRY(list->head, node)
 	{
 		pkg_fragment_t *frag = node->data;
+		int got_flags = 0;
 
-		if ((want_flags & PKG_LIBS_ONLY_LDPATH) == PKG_LIBS_ONLY_LDPATH && frag->type != 'L')
-			continue;
-		else if ((want_flags & PKG_LIBS_ONLY_LIBNAME) == PKG_LIBS_ONLY_LIBNAME && frag->type != 'l')
-			continue;
-		else if ((want_flags & PKG_LIBS_ONLY_OTHER) == PKG_LIBS_ONLY_OTHER && (frag->type == 'l' || frag->type == 'L'))
+		switch (frag->type)
+		{
+			case 'L': got_flags = PKG_LIBS_ONLY_LDPATH; break;
+			case 'l': got_flags = PKG_LIBS_ONLY_LIBNAME; break;
+			default: got_flags = PKG_LIBS_ONLY_OTHER; break;
+		}
+
+		if ((want_flags & got_flags) == 0)
 			continue;
 
 		print_fragment(frag);
@@ -272,11 +298,22 @@ print_variable(pkg_t *pkg, void *data, unsigned int flags)
 	{
 		if (*(req->buf) == '\0')
 		{
-			strlcpy(req->buf, var, sizeof(req->buf));
+			memset(req->buf, 0, sizeof(req->buf));
+
+			if (*var == '/' && (flags & PKGF_MUNGE_SYSROOT_PREFIX) &&
+			    (sysroot_dir != NULL && strncmp(var, sysroot_dir, strlen(sysroot_dir))))
+				strlcat(req->buf, sysroot_dir, sizeof(req->buf));
+
+			strlcat(req->buf, var, sizeof(req->buf));
 			return;
 		}
 
 		strlcat(req->buf, " ", sizeof(req->buf));
+
+		if (*var == '/' && (flags & PKGF_MUNGE_SYSROOT_PREFIX) &&
+		    (sysroot_dir != NULL && strncmp(var, sysroot_dir, strlen(sysroot_dir))))
+			strlcat(req->buf, sysroot_dir, sizeof(req->buf));
+
 		strlcat(req->buf, var, sizeof(req->buf));
 	}
 }
@@ -556,11 +593,11 @@ main(int argc, char *argv[])
 		{ "help", no_argument, &want_flags, PKG_HELP, },
 		{ "env-only", no_argument, &want_flags, PKG_ENV_ONLY, },
 		{ "print-requires-private", no_argument, &want_flags, PKG_REQUIRES_PRIVATE, },
-		{ "cflags-only-I", no_argument, &want_flags, PKG_CFLAGS|PKG_CFLAGS_ONLY_I|PKG_PRINT_ERRORS, },
-		{ "cflags-only-other", no_argument, &want_flags, PKG_CFLAGS|PKG_CFLAGS_ONLY_OTHER|PKG_PRINT_ERRORS, },
-		{ "libs-only-L", no_argument, &want_flags, PKG_LIBS|PKG_LIBS_ONLY_LDPATH|PKG_PRINT_ERRORS, },
-		{ "libs-only-l", no_argument, &want_flags, PKG_LIBS|PKG_LIBS_ONLY_LIBNAME|PKG_PRINT_ERRORS, },
-		{ "libs-only-other", no_argument, &want_flags, PKG_LIBS|PKG_LIBS_ONLY_OTHER|PKG_PRINT_ERRORS, },
+		{ "cflags-only-I", no_argument, &want_flags, PKG_CFLAGS_ONLY_I|PKG_PRINT_ERRORS, },
+		{ "cflags-only-other", no_argument, &want_flags, PKG_CFLAGS_ONLY_OTHER|PKG_PRINT_ERRORS, },
+		{ "libs-only-L", no_argument, &want_flags, PKG_LIBS_ONLY_LDPATH|PKG_PRINT_ERRORS, },
+		{ "libs-only-l", no_argument, &want_flags, PKG_LIBS_ONLY_LIBNAME|PKG_PRINT_ERRORS, },
+		{ "libs-only-other", no_argument, &want_flags, PKG_LIBS_ONLY_OTHER|PKG_PRINT_ERRORS, },
 		{ "uninstalled", no_argument, &want_flags, PKG_UNINSTALLED, },
 		{ "no-uninstalled", no_argument, &want_flags, PKG_NO_UNINSTALLED, },
 		{ "keep-system-cflags", no_argument, &want_flags, PKG_KEEP_SYSTEM_CFLAGS, },
@@ -574,6 +611,7 @@ main(int argc, char *argv[])
 		{ "list-all", no_argument, &want_flags, PKG_LIST|PKG_PRINT_ERRORS, },
 		{ "simulate", no_argument, &want_flags, PKG_SIMULATE, },
 		{ "no-cache", no_argument, &want_flags, PKG_NO_CACHE, },
+		{ "debug", no_argument, &want_flags, 0, },
 		{ NULL, 0, NULL, 0 }
 	};
 
@@ -619,14 +657,6 @@ main(int argc, char *argv[])
 	else
 		want_flags &= ~(PKG_SILENCE_ERRORS);
 
-	if ((want_flags & PKG_LIBS_ONLY_LIBNAME) == PKG_LIBS_ONLY_LIBNAME)
-		want_flags &= ~(PKG_LIBS_ONLY_OTHER|PKG_LIBS_ONLY_LDPATH);
-	else if ((want_flags & PKG_LIBS_ONLY_LDPATH) == PKG_LIBS_ONLY_LDPATH)
-		want_flags &= ~(PKG_LIBS_ONLY_OTHER);
-
-	if ((want_flags & PKG_CFLAGS_ONLY_I) == PKG_CFLAGS_ONLY_I)
-		want_flags &= ~(PKG_CFLAGS_ONLY_OTHER);
-
 	if ((want_flags & PKG_ABOUT) == PKG_ABOUT)
 	{
 		about();
@@ -910,7 +940,7 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if ((want_flags & PKG_CFLAGS) == PKG_CFLAGS)
+	if ((want_flags & PKG_CFLAGS))
 	{
 		pkg_list_t frag_list = PKG_LIST_INITIALIZER;
 
@@ -921,7 +951,7 @@ main(int argc, char *argv[])
 		}
 	}
 
-	if ((want_flags & PKG_LIBS) == PKG_LIBS)
+	if ((want_flags & PKG_LIBS))
 	{
 		pkg_list_t frag_list = PKG_LIST_INITIALIZER;
 
